package
Version:
v0.0.0-...-c04ea6e
Opens a new window with list of versions in this module.
Published: Jun 11, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Logger interface {
Log(location string, message string)
ErrorsCount() int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.